@@ -16,10 +16,18 @@ License for the specific language governing permissions and limitations
 under the License.
 """
 
+# Main logging file
+PYSTOL_LOG_FILE = '/var/log/pystol.log'
+
+# Current branch
+PYSTOL_BRANCH = 'master'
+
 # CRD Settings
 CRD_DOMAIN = 'pystol.org'
+CRD_GROUP = 'pystol.org'
 CRD_VERSION = 'v1alpha1'
 CRD_PLURAL = 'pystolactions'
+CRD_NAMESPACE = 'pystol'
 
 # Type methods maps
 LIST_TYPES_MAP = {
